//
//  OpenFeedback.h
//  OpenFeedback
//
//  Created by Tyler Hall on 12/27/09.
//  Modified by Julián Romero on June 2011.
//  Copyright 2009 Click On Tyler, LLC. All rights reserved.
//

#import <Cocoa/Cocoa.h>

@protocol OpenFeedbackDelegate <NSObject>

#if OF_USE_SMTP

@required

/*! STMP server address or host name. */
- (NSString *)smtpHost;

/*! SMTP account login. */
- (NSString *)smtpLogin;

/*! SMTP account password. Use an account just for this. It will be easily hacked. */
- (NSString *)smtpPassword;

/*! App support account. It can include a name. Example: Cool App <coolapp@example.com> 
 *  It will be used as 'From' and 'Reply-to' message fields. 
 *  Visible to users who decides to receive a copy. 
 */
- (NSString *)supportAddress;

#endif

#if OF_SEND_LOG
@required

/*! Log absolute path. */
- (NSString *)logPath;

#endif

@optional

/* Give an opportunity to delegate object to send the feedback itself. */
- (BOOL)openFeedback:(id)feedbackController willSendData:(NSDictionary *)data;

@end


@interface OpenFeedback : NSObject 
{
	id _of_window_controller;
	id delegate;
}

/*! Create an OpendFeedback object for those not embedding it on a NIB. */
+ (id)feedbackController;

/*! Open panel for support requests. */
- (IBAction)presentFeedbackPanelForSupport:(id)sender;

/*! Open panel for feature requests. */
- (IBAction)presentFeedbackPanelForFeature:(id)sender;

/*! Open panel for bug reports. */
- (IBAction)presentFeedbackPanelForBug:(id)sender;

@property (assign)                      id<OpenFeedbackDelegate> delegate;
@property (nonatomic, retain, readonly) id                       windowController;

@end


@interface OpenFeedback (CrashReporter)

/*! Check whether or not there are fresh crash logs. */
+ (BOOL)hasCrashLogs;

/*! Open panel for bug report and initialize with latest crash logs. */
- (IBAction)presentFeedbackPanelForBugWithCrashLogs:(id)sender;

@end
